<?php
/*
Plugin Name: CSS3 Pricing Tables WPress
Plugin URI: http://yougapi.com/products/wp/demo/pricing-tables/
Description: Integrate Awesome CSS3 Pricing tables into your WordPress.
Version: 1.2
Author: Yougapi Technology LLC
Author URI: http://yougapi.com
*/

require_once dirname( __FILE__ ).'/include/wpress_framework/WPress_framework.php';
require_once dirname( __FILE__ ).'/pricing_wpress_db.php';
//require_once dirname( __FILE__ ).'/pricing_wpress_settings.php';
require_once dirname( __FILE__ ).'/pricing_wpress_display.php';

class Pricing_wpress {
	
	function Pricing_wpress() {
		if(is_admin()) {
			require_once dirname( __FILE__ ).'/pricing_wpress_admin.php';
			//activation
			register_activation_hook(__FILE__, array(__CLASS__, 'on_plugin_activation'));
			//AJAX
			add_action( 'wp_ajax_nopriv_pricing_wpress_listener', array(__CLASS__, 'pricing_wpress_listener') );
			add_action( 'wp_ajax_pricing_wpress_listener', array(__CLASS__, 'pricing_wpress_listener') );
		}
		
		add_filter('the_posts', array(__CLASS__, 'add_css'));
		//add_filter('wp_enqueue_scripts', array(__CLASS__, 'add_css'));
		
		//shortcodes
		add_shortcode( 'pricing_wpress', array(__CLASS__, 'display_pricing_table') );
	}
	
	function add_css($posts){
		if (empty($posts)) return $posts;
	 	
		$pos = stripos($posts[0]->post_content, '[pricing_wpress');
		
		if($pos>=0) {
			//find the style id
			$shortcode_found = substr($posts[0]->post_content,$pos,50);
			$style_pos = stripos($shortcode_found, 'style="');
			$style_shortcode = substr($shortcode_found,$style_pos,10);
			preg_match('/[0-9]/', $style_shortcode, $matches);
			$style = $matches[0];
			
			//which style?
			if($style==1) $style_page='style_1';
			elseif($style==2) $style_page='style_2';
			elseif($style==3) $style_page='style_3';
			elseif($style==4) $style_page='style_4';
			elseif($style==5) $style_page='style_5';
			elseif($style==6) $style_page='style_6';
			elseif($style==7) $style_page='style_7';
			elseif($style==8) $style_page='style_8';
			else $style_page='style_1';
			
			wp_enqueue_style( 'pricing_table_main', plugin_dir_url( __FILE__ ).'include/css/main.css');
			wp_enqueue_style( 'pricing_table_style1', plugin_dir_url( __FILE__ ).'include/css/'.$style_page.'.css');
		}
	 	
		return $posts;
	}
	
	//display through a shortcode
	function display_pricing_table($atts, $content = null, $code) {
		extract(shortcode_atts(array(
		'id' => '',
		'style' => ''
		), $atts));
		
		if($style=='') $style='1';
		
		$d1 = new Pricing_wpress_display();
		$pricing_table = $d1->get_pricing_table($id);
		
		return '<p>'.$pricing_table.'<div style="clear:both;"></div></p>';
	}
	
	//AJAX calls
	function pricing_wpress_listener() {
		
		$method = $_POST['method'];
		
		if($method=='save_pricing_table_structure') {
			//post data
			$id = $_POST['id'];
			$name = $_POST['name'];
			$nb_columns = $_POST['nb_columns'];
			$nb_lines = $_POST['nb_lines'];
			$line_height = $_POST['line_height'];
			$columns_width = $_POST['columns_width'];
			$caption_columns_width = $_POST['caption_columns_width'];
			$currency = $_POST['currency'];
			$caption_column_state = $_POST['caption_column_state'];
			
			$db1 = new Pricing_wpress_db();
			
			//Add a new table
			if($id=='') {
				$inserted_id = $db1->add_pricing_table(array('name'=>$name, 'nb_columns'=>$nb_columns, 'nb_lines'=>$nb_lines, 'line_height'=>$line_height, 'columns_width'=>$columns_width, 'caption_columns_width'=>$caption_columns_width, 'currency'=>$currency, 'caption_column_state'=>$caption_column_state));
				echo $inserted_id;
			}
			//Edit existing table
			else {
				$db1->update_pricing_table_structure(array('name'=>$name, 'nb_columns'=>$nb_columns, 'nb_lines'=>$nb_lines, 'line_height'=>$line_height, 'columns_width'=>$columns_width, 'caption_columns_width'=>$caption_columns_width, 'currency'=>$currency, 'caption_column_state'=>$caption_column_state), $id);
				echo $id;
			}
		}
		else if($method=='save_table_content') {
			$id = $_POST['id'];
			$content = stripslashes($_POST['content']);
			//$content = $_POST['content'];
			$nb_columns = $_POST['nb_columns'];
			$nb_lines = $_POST['nb_lines'];
			
			//print_r($content);
			
			if($id!=''&&$nb_columns>0&&$nb_lines>0) {
				$content = json_decode($content,true);
				//print_r($content);
				
				$table_content = self::format_table_content($content, $nb_columns, $nb_lines);
				
				//print_r($table_content);
				
				$db1 = new Pricing_wpress_db();
				$db1->update_pricing_table_content(array('table_content'=>$table_content), $id);
			}
		}
		else if($method=='delete_table') {
			$id = $_POST['id'];
			
			if($id!='') {
				$db1 = new Pricing_wpress_db();
				$db1->delete_pricing_table($id);
			}
		}
		
		exit;
	}
	
	function on_plugin_activation() {
		$db1 = new Pricing_wpress_db();
		$db1->create_pricing_table();
	}
	
	function format_table_structure($table) {
		$nb_columns = '"nb_columns":"'.$table['nb_columns'].'"';
		$nb_lines = '"nb_lines":"'.$table['nb_lines'].'"';
		$line_height = '"line_height":"'.$table['line_height'].'"';
		$columns_width = '"columns_width":"'.$table['columns_width'].'"';
		$caption_columns_width = '"caption_columns_width":"'.$table['caption_columns_width'].'"';
		$currency = '"currency":"'.$table['currency'].'"';
		$caption_column_state = '"caption_column_state":"'.$table['caption_column_state'].'"';
		
		$table_structure = $nb_columns.','.$nb_lines.','.$line_height.','.$columns_width.','.$caption_columns_width.','.$currency.','.$caption_column_state;
		
		return $table_structure;
	}
	
	function format_table_content($content, $nb_columns, $nb_lines) {
		
		$caption_header = urldecode($content['caption_header']);
		$caption_header = str_replace('"',"",$caption_header); //delete any "
		$caption_header = '"'.addslashes($caption_header).'"';
		
		$caption_title = self::simple_array_to_json($content['caption_title']);
		$column_title = self::simple_array_to_json($content['column_title']);
		$column_price = self::simple_array_to_json($content['column_price']);
		$column_note = self::simple_array_to_json($content['column_note']);
		$button_title = self::simple_array_to_json($content['button_title']);
		$button_link = self::simple_array_to_json($content['button_link']);
		
		if($caption_header=='') $caption_header='""';
		if($caption_title=='') $caption_title='""';
		if($column_title=='') $column_title='""';
		if($column_price=='') $column_price='""';
		if($column_note=='') $column_note='""';
		if($button_title=='') $button_title='""';
		if($button_link=='') $button_link='""';
		
		$caption_header = '"caption_header":'.$caption_header;
		$caption_title = '"caption_title":'.$caption_title;
		$column_title = '"column_title":'.$column_title;
		$column_price = '"column_price":'.$column_price;
		$column_note = '"column_note":'.$column_note;
		$button_title = '"button_title":'.$button_title;
		$button_link = '"button_link":'.$button_link;
		
		//adjustement because index 0 is always empty...
		if(count($content['line'])>$nb_columns) $nb_columns=count($content['line']);
		
		for($i=0; $i<$nb_columns; $i++) {
			$line .= self::simple_array_to_json($content['line'][$i]);
			if($i<($nb_columns-1)) $line .= ',';
		}
		if($line!='') $line = '"line":['.$line.']';
		else $line = '"line":""';
		
		$json_str = '"content":{'.$caption_header.','.$caption_title.','.$column_title.','.$column_price.','.$column_note.','.$button_title.','.$button_link.','.$line.'}';
		
		return $json_str;
	}
	
	//Receives one dimension array and returns a json format
	function simple_array_to_json($array) {
		$str='';
		for($i=0; $i<count($array); $i++) {
			$tmp = urldecode($array[$i]);
			$tmp = str_replace('"',"",$tmp); //delete any "
			$tmp = addslashes($tmp);
			
			$str .= '"'.$tmp.'"';
			if($i<(count($array)-1)) $str .= ',';
		}
		if($str!='') $str = '['.$str.']';
		else $str='""';
		return $str;
	}
}

new Pricing_wpress();

?>